Suite class

Describes a suite of tests

Annotations
  • @freezed

Constructors

Suite({String? path, required String platform, required List<Test> allTests})
Factory constructor to create a Suite
factory

Properties

allTests → List<Test>
All Tests contained within this suite
no setterinherited
copyWith → $SuiteCopyWith<Suite>
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
hidden → List<Test>
All hidden Tests
no setter
path → String?
Optional path to this suite's file
no setterinherited
platform → String
Platform on which this suite is running
no setterinherited
problems → List<Test>
All non-hidden Tests with problems
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
skipped → List<Test>
All non-hidden skipped Tests
no setter
tests → List<Test>
All non-hidden Tests
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited