Test class

Describes a test

Annotations
  • @freezed

Constructors

Test({required int suiteId, required String name, required int startTime, String? url, String? rootUrl, @Default.new(-1) int endTime, @Default.new(false) bool hidden, @Default.new(false) bool skipped, required List<Problem> problems, required List<String> prints})
Factory constructor to create a Test
factory

Properties

copyWith → $TestCopyWith<Test>
no setterinherited
duration → int
The time (in milliseconds) that elapsed between this test starting and completing.
no setter
endTime → int
The time (in milliseconds) that has elapsed between the test runner starting and this test completing.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
hidden → bool
Whether this test's result should be hidden.
no setterinherited
name → String
The name of this test, including prefixes from any containing groups.
no setterinherited
prints → List<String>
A list of any messages emitted during this test.
no setterinherited
problems → List<Problem>
A list of any problems that occured during this test.
no setterinherited
rootUrl → String?
Optional URL for the original test suite in which this test was defined
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
skipped → bool
Whether this test (or some part of it) was skipped.
no setterinherited
startTime → int
The time (in milliseconds) that has elapsed between the test runner starting and this test starting.
no setterinherited
suiteId → int
The id of the suite to which this test belongs.
no setterinherited
url → String?
Optional URL for the file in which this test was defined
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited